==> 6.0.3.tar.gz: lib/backendless_sdk.dart <==
library backendless_sdk;

import 'dart:collection';
import 'dart:io';
import 'dart:typed_data';
import 'dart:ui' show hashValues;
import 'dart:convert';

import 'package:collection/collection.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:reflectable/reflectable.dart';

import 'package:http/http.dart' as http;

import 'src/utils/utils.dart';

part 'src/modules/common/invoker.dart';
part 'src/modules/common/prefs.dart';
part 'src/modules/common/exception.dart';

part 'src/modules/cache/cache.dart';
part 'src/modules/cache/cache_service.dart';
part 'src/modules/commerce/commerce.dart';
part 'src/modules/commerce/status.dart';
part 'src/modules/counters/counters.dart';
part 'src/modules/counters/atomic_service.dart';
part 'src/modules/custom_service.dart';
part 'src/modules/data/data.dart';
part 'src/modules/data/data_query_builder.dart';
part 'src/modules/data/data_store.dart';
part 'src/modules/data/property.dart';
part 'src/modules/data/rt.dart';
part 'src/modules/data/reflector.dart';
part 'src/modules/data/map_to_property.dart';
part 'src/modules/data/types.dart';
part 'src/modules/events.dart';
part 'src/modules/files/files.dart';
part 'src/modules/files/file_info.dart';
part 'src/modules/geo/geo.dart';
part 'src/modules/geo/geo_query.dart';
part 'src/modules/geo/geo_point.dart';
part 'src/modules/geo/geo_category.dart';
part 'src/modules/logging/logging.dart';
part 'src/modules/logging/logger.dart';
part 'src/modules/messaging/messaging.dart';
part 'src/modules/messaging/channel.dart';
part 'src/modules/messaging/options.dart';
part 'src/modules/messaging/user_status.dart';
part 'src/modules/messaging/device_registration.dart';
part 'src/modules/messaging/status.dart';
part 'src/modules/messaging/command.dart';
part 'src/modules/messaging/email.dart';
part 'src/modules/rt.dart';
part 'src/modules/user_service/user_service.dart';
part 'src/modules/user_service/user.dart';
part 'src/modules/user_service/user_property.dart';
part 'src/utils/message_codec.dart';
part 'src/utils/query_builder.dart';
part 'src/utils/headers.dart';
part 'src/backendless.dart';
part 'src/modules/geo/geomerty/spatial_reference_system.dart';
part 'src/modules/geo/geomerty/spatial_reference_manager.dart';
part 'src/modules/geo/geomerty/geometry.dart';
part 'src/modules/geo/geomerty/wkt_parser.dart';
part 'src/modules/geo/geomerty/geo_json_parser.dart';
part 'src/modules/geo/geomerty/point.dart';
part 'src/modules/geo/geomerty/line_string.dart';
part 'src/modules/geo/geomerty/polygon.dart';

part 'src/modules/transaction/common/operation.dart';
part 'src/modules/transaction/common/isolation_level.dart';
part 'src/modules/transaction/common/operation_error.dart';
part 'src/modules/transaction/common/operation_result.dart';
part 'src/modules/transaction/common/operation_type.dart';
part 'src/modules/transaction/common/uow_result.dart';
part 'src/modules/transaction/common/payload/bulk.dart';
part 'src/modules/transaction/common/payload/relation.dart';
part 'src/modules/transaction/common/payload/selector.dart';

part 'src/modules/transaction/op_result.dart';
part 'src/modules/transaction/relation_operation.dart';
part 'src/modules/transaction/uow.dart';
part 'src/modules/transaction/uow_create.dart';
part 'src/modules/transaction/uow_delete.dart';
part 'src/modules/transaction/uow_update.dart';
part 'src/modules/transaction/uow_find.dart';
part 'src/modules/transaction/uow_executor.dart';
part 'src/modules/transaction/helper.dart';

==> 7.3.3.tar.gz: lib/backendless_sdk.dart <==
library backendless_sdk;

import 'dart:collection';
import 'dart:io';
import 'dart:convert';

import 'package:collection/collection.dart';
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';
import 'package:reflectable/reflectable.dart';

import 'package:http/http.dart' as http;

import 'src/utils/utils.dart';

part 'src/modules/common/invoker.dart';
part 'src/modules/common/prefs.dart';
part 'src/modules/common/exception.dart';

part 'src/modules/cache/cache.dart';
part 'src/modules/cache/cache_service.dart';
part 'src/modules/commerce/commerce.dart';
part 'src/modules/commerce/status.dart';
part 'src/modules/counters/counters.dart';
part 'src/modules/counters/atomic_service.dart';
part 'src/modules/custom_service.dart';
part 'src/modules/data/data.dart';
part 'src/modules/data/data_query_builder.dart';
part 'src/modules/data/data_store.dart';
part 'src/modules/data/property.dart';
part 'src/modules/data/rt.dart';
part 'src/modules/data/reflector.dart';
part 'src/modules/data/map_to_property.dart';
part 'src/modules/data/types.dart';
part 'src/modules/data/json/json_builder.dart';
part 'src/modules/data/relation_status.dart';
part 'src/modules/events.dart';
part 'src/modules/files/files.dart';
part 'src/modules/files/file_info.dart';
part 'src/modules/logging/logging.dart';
part 'src/modules/logging/logger.dart';
part 'src/modules/messaging/messaging.dart';
part 'src/modules/messaging/channel.dart';
part 'src/modules/messaging/options.dart';
part 'src/modules/messaging/user_status.dart';
part 'src/modules/messaging/device_registration.dart';
part 'src/modules/messaging/status.dart';
part 'src/modules/messaging/command.dart';
part 'src/modules/messaging/email.dart';
part 'src/modules/rt.dart';
part 'src/modules/invoke_options.dart';
part 'src/modules/execution_type.dart';
part 'src/modules/user_service/user_service.dart';
part 'src/modules/user_service/user.dart';
part 'src/modules/user_service/user_property.dart';
part 'src/utils/message_codec.dart';
part 'src/utils/query_builder.dart';
part 'src/utils/headers.dart';
part 'src/backendless.dart';
part 'src/modules/data/geo/spatial_reference_system.dart';
part 'src/modules/data/geo/spatial_reference_manager.dart';
part 'src/modules/data/geo/geometry.dart';
part 'src/modules/data/geo/wkt_parser.dart';
part 'src/modules/data/geo/geo_json_parser.dart';
part 'src/modules/data/geo/point.dart';
part 'src/modules/data/geo/line_string.dart';
part 'src/modules/data/geo/polygon.dart';

part 'src/modules/transaction/common/operation.dart';
part 'src/modules/transaction/common/isolation_level.dart';
part 'src/modules/transaction/common/operation_error.dart';
part 'src/modules/transaction/common/operation_result.dart';
part 'src/modules/transaction/common/operation_type.dart';
part 'src/modules/transaction/common/uow_result.dart';
part 'src/modules/transaction/common/payload/bulk.dart';
part 'src/modules/transaction/common/payload/relation.dart';
part 'src/modules/transaction/common/payload/selector.dart';

part 'src/modules/transaction/op_result.dart';
part 'src/modules/transaction/relation_operation.dart';
part 'src/modules/transaction/uow.dart';
part 'src/modules/transaction/uow_create.dart';
part 'src/modules/transaction/uow_delete.dart';
part 'src/modules/transaction/uow_update.dart';
part 'src/modules/transaction/uow_upsert.dart';
part 'src/modules/transaction/uow_find.dart';
part 'src/modules/transaction/uow_executor.dart';
part 'src/modules/transaction/helper.dart';
